Getting Started - Nautobot Documentation

Skip to content

# Introduction and Scope

The audience for this user guide is users new to Nautobot. This guide will demonstrate how to use and perform common operations in Nautobot's Web UI.

It is intended to assist the user with:

- Understanding the prerequisites for adding a new Device
- Creating the necessary prerequisite objects to add a new Device
- Adding new Devices
- Adding and understanding Location Types and Locations
- Adding and understanding Platforms
- Adding and understanding Tenants and Tenant Groups
- Adding Interfaces to a Device
- Adding VLANs and understanding VLAN Groups
- Understanding IP Address Management (IPAM) in Nautobot
- How to navigate to the object you are interested in
- How to use the Search Bar to find the object you are interested in

This guide does not cover every possible operation in Nautobot's Web UI. However, after reading this guide and working through the included exercises, the user should have a good feel for:

- Performing basic tasks
- How to navigate to a specific object and its related objects
- The Web UI's general structure and organization
- Extrapolating to use the Web UI for almost any task

## Requirements

1. A functional Nautobot installation